.. _substance_d:

Substance D
===========

Overview
--------

Substance D is an application server built using the :term:`Pyramid` web
framework. It can be used as a base to build a general-purpose web application
like a blog, a shopping cart application, a scheduling application, or any
other web app that requires both an administration and a retail interface.

Substance D owes much of its spirit to the :term:`Zope` application server.

It requires Python 2.7, 3.4, or 3.5.

Installation
------------
See :doc:`install`.

Demonstration Application
-------------------------

See the application running at http://demo.substanced.net for a demonstration
of the Substance D management interface.

Narrative Documentation
-----------------------

.. toctree::
   :maxdepth: 1

   install
   intro
   sdi
   content
   mgmtview
   forms
   services
   cataloging
   references
   workflows
   dump
   evolution
   folder_contents
   audit
   locking
   configuration
   statistics
   vrooting
   retail
   scripts
   magic

API Documentation
-----------------

.. toctree::
   :maxdepth: 1

   api
   permissions

.. _support-reporting-bugs-development-versions:

Support / Reporting Bugs / Development Versions
-----------------------------------------------

Visit http://github.com/Pylons/substanced to download development or tagged
versions.

Visit http://github.com/Pylons/substanced/issues to report bugs.

The mailing list exists at https://groups.google.com/group/substanced-users

The IRC channel is at irc://freenode.net/#substanced

Copyright, Trademarks, and Attributions
---------------------------------------

.. toctree::
   :maxdepth: 1

   copyright

Indices and tables
------------------

* :ref:`glossary`
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. add glossary in a hidden toc to avoid warnings

.. toctree::
   :hidden:

   glossary
